@@ -26,7 +26,7 @@ or with a python-like shorthand
 import sys, os, re, sqlpython, pyparsing, re, completion
 import datetime, pickle, binascii, subprocess, time, itertools, hashlib
 import traceback, operator
-from cmd2 import Cmd, make_option, options, Statekeeper, Cmd2TestCase
+from cmd2 import Cmd, make_option, options, Statekeeper, Cmd2TestCase, options_defined
 from output_templates import output_templates
 from metadata import metaqueries
 from plothandler import Plot
@@ -358,6 +358,9 @@ class Abbreviatable_List(list):
             raise ValueError, 'Too many matches: %s' % str(result)
         return result[0]
     
+# TODO: read comments in psql
+# ls -l
+
 class sqlpyPlus(sqlpython.sqlpython):
     defaultExtension = 'sql'
     abbrev = True    
@@ -391,8 +394,11 @@ class sqlpyPlus(sqlpython.sqlpython):
         heading
         wildsql          Accept wildcards, position #s in column names
         version'''
-    
+        
     def __init__(self):
+        # override commentGrammars before top-level __init__, or they won't affect self.parser
+        self.doubleDashComment = pyparsing.NotAny(pyparsing.Or(options_defined)) + pyparsing.Literal('--') + pyparsing.restOfLine        
+        self.commentGrammars = pyparsing.Or([pyparsing.cStyleComment, self.doubleDashComment])
         sqlpython.sqlpython.__init__(self)
         self.binds = CaselessDict()
         if self.settable.has_key('case_insensitive'):
@@ -413,7 +419,6 @@ class sqlpyPlus(sqlpython.sqlpython):
         self.rdbms_supported = Abbreviatable_List('oracle postgres mysql'.split())
         self.version = 'SQLPython %s' % sqlpython.__version__
         self.pystate = {'r': [], 'binds': self.binds, 'substs': self.substvars}
-        self.commentGrammars = pyparsing.Or([pyparsing.cStyleComment, self.doubleDashComment])
         
     # overrides cmd's parseline
     def parseline(self, line):
@@ -444,7 +449,7 @@ class sqlpyPlus(sqlpython.sqlpython):
     def dbms_output(self):
         "Dumps contents of Oracle's DBMS_OUTPUT buffer (where PUT_LINE goes)"
         try:
-            line = self.curs.var(cx_Oracle.STRING) # TODO: would regular string and number work?
+            line = self.curs.var(cx_Oracle.STRING) 
             status = self.curs.var(cx_Oracle.NUMBER)
             self.curs.callproc('dbms_output.get_line', [line, status])
             while not status.getvalue():
@@ -1242,7 +1247,7 @@ class sqlpyPlus(sqlpython.sqlpython):
             self.perror(self.do_psql.__doc__)
             
     def _do_dir(self, type, arg, opts):
-        self.do_ls("%s/%s%s%s" % (type, str(arg), arg.parsed.terminator, arg.parsed.suffix), opts)
+        self._do_ls("%s/%s%s%s" % (type, str(arg), arg.parsed.terminator, arg.parsed.suffix), opts)
 
     standard_options = [
               all_users_option,
@@ -1378,7 +1383,10 @@ class sqlpyPlus(sqlpython.sqlpython):
 
         '''
         #TODO: quoted assignments currently failing?
-        arg = self.parsed(arg)
+        #arg = self.parsed(arg)
+        if hasattr(arg, 'parsed'):
+            arg = arg.parsed.raw
+        arg = arg.strip('\n;').lstrip(':')
         try:
             var, val = self.assignmentSplitter.split(arg, maxsplit=1)
         except ValueError:
@@ -1579,18 +1587,22 @@ class sqlpyPlus(sqlpython.sqlpython):
             if descrip.match_pattern(seek, specific_owner = ((not opts.all) and username)):
                 yield descrip
    
-    @options(standard_options)
-    def do_ls(self, arg, opts):
-        '''
-        Lists objects as through they were in an {object_type}/{object_name} UNIX
-        directory structure.  `*` and `%` may be used as wildcards.
-        '''
+    def _do_ls(self, arg, opts):
+        'Functional core of ``do_ls``, split out into an undecorated version to be callable from other methods'
         opts.exact = True
         (username, schemas) = self.metadata()
         result = [descrip.path for descrip in self._matching_database_objects(arg, opts)]
         if result:
             result.sort(reverse=bool(opts.reverse))
             self.poutput('\n'.join(result))
+                
+    @options(standard_options)
+    def do_ls(self, arg, opts):
+        '''
+        Lists objects as through they were in an {object_type}/{object_name} UNIX
+        directory structure.  `*` and `%` may be used as wildcards.
+        '''
+        return self._do_ls(arg, opts)
         
     @options([make_option('-i', '--ignore-case', dest='ignorecase', action='store_true', help='Case-insensitive search'),
               make_option('-a', '--all', action='store_true', help="all schemas' objects")])     
@@ -1668,7 +1680,7 @@ class sqlpyPlus(sqlpython.sqlpython):
 
     def cmdloop(self):
         # TODO: args past ; don't even get into sys.argv
-        if sys.argv[1] in ('--test', '-t'):
+        if (len(sys.argv) > 1) and sys.argv[1] in ('--test', '-t'):
             self.runTranscriptTests(sys.argv[2:])
         else:
             self.run_commands_at_invocation(sys.argv[1:])
