@@ -116,7 +116,7 @@ class sqlpython(cmd2.Cmd):
                                     help='close connection {N} (or current)'),
                    cmd2.make_option('-C', '--closeall', action='store_true',
                                     help='close all connections'),
-                   cmd2.make_option('--postgres', action='store_true', help='Connect to postgreSQL: `sqlpython --postgres [DBNAME [USERNAME]]`'),
+                   cmd2.make_option('--postgres', action='store_true', help='Connect to postgreSQL: `connect --postgres [DBNAME [USERNAME]]`'),
                    cmd2.make_option('--oracle', action='store_true', help='Connect to an Oracle database'),
                    cmd2.make_option('--mysql', action='store_true', help='Connect to a MySQL database'),
                    cmd2.make_option('-H', '--hostname', type='string',
@@ -131,7 +131,13 @@ class sqlpython(cmd2.Cmd):
                                     help='Database user name to connect as')])
     def do_connect(self, arg, opts):
  
-        '''Opens the DB connection'''
+        '''Opens the DB connection.  Some sample valid connection strings:
+        
+        connect oracle://user:password@SID
+        connect postgres://user:password@hostname/dbname
+        connect user/password@SID  (Oracle is the default RDBMS target)
+        connect --postgres --hostname=hostname dbname username
+        connect --mysql dbname username'''
         if opts.closeall:
             self.closeall()
             return 
@@ -145,8 +151,12 @@ class sqlpython(cmd2.Cmd):
             return 
         if self.successfully_connect_to_number(arg):
             return
-        
-        db_instance = connections.DatabaseInstance(arg, opts, default_rdbms = self.default_rdbms)
+
+        try:
+            db_instance = connections.DatabaseInstance(arg, opts, default_rdbms = self.default_rdbms)
+        except:
+            self.perror('Connection failure.\n' + self.do_connect.__doc__)
+            return
         if opts.add or (self.instance_number is None):
             try:
                 self.instance_number = max(self.instances.keys()) + 1
@@ -157,11 +167,11 @@ class sqlpython(cmd2.Cmd):
         self.make_instance_current(self.instance_number)        
         if (self.rdbms == 'oracle') and self.serveroutput:
             self.current_instance.connection.cursor().callproc('dbms_output.enable',[])
-            #self.curs.callproc('dbms_output.enable', [])        
     
     def do_pickle(self, arg):
         self.current_instance.pickle()
         
+    _availability_regex = re.compile(r'\(\s*Availab(.*)\)', re.IGNORECASE )        
     def postparsing_precmd(self, statement):
         stop = 0
         self.saved_instance_number = None
@@ -174,10 +184,21 @@ class sqlpython(cmd2.Cmd):
             except KeyError:
                 self.list_instances()
                 raise KeyError, 'No connection #%s' % statement.parsed.instance_number
+        try:
+            method = getattr(self, 'do_' + statement.parsed.command)
+            availability = self._availability_regex.search(method.__doc__ or '')
+            if availability and (self.current_instance.rdbms not in availability.group(1).lower()):
+                raise NotImplementedError, '``%s`` unavailable for %s' % (
+                    statement.parsed.command, self.current_instance.rdbms)
+        except AttributeError:
+            pass
         return stop, statement           
     def postparsing_postcmd(self, stop):
-        if self.saved_instance_number is not None:
-            self.successfully_connect_to_number(self.saved_instance_number)
+        try:
+            if self.saved_instance_number is not None:
+                self.successfully_connect_to_number(self.saved_instance_number)
+        except AttributeError:
+            pass  # no saved_instance_number has been defined
         return stop
                 
     do_host = cmd2.Cmd.do_shell
